//ganglia_metric.cc: Ganglia Metric Plugin
// Author: Eric Flumerfelt
// Last Modified: 11/14/2014
//
// An implementation of the MetricPlugin interface for Ganglia

#ifndef __GANGLIA_METRIC__
#define __GANGLIA_METRIC__ 1

#include "fhiclcpp/fwd.h"
#include "artdaq-utilities/Plugins/MetricMacros.hh"
#include "send_gmetric.h"

namespace artdaq {

	class GangliaMetric : public MetricPlugin {
	private:
		std::string configFile_;
		std::string group_;
		std::string cluster_;

	public:
		GangliaMetric(fhicl::ParameterSet pset) : MetricPlugin(pset),
			configFile_(pset.get<std::string>("configFile", "/etc/ganglia/gmond.conf")),
			group_(pset.get<std::string>("group", "ARTDAQ")),
			cluster_(pset.get<std::string>("cluster", ""))
		{
		  init_gmetric(configFile_.c_str());
		}

		virtual ~GangliaMetric()
		{
			stopMetrics();
			destroy_gmetric();
		}

		std::string getLibName() { return "ganglia"; }
		void stopMetrics_() { }
		void startMetrics_() { }

		void sendMetric_(std::string name, std::string value, std::string unit)
		{
			send_gmetric(name.c_str(), value.c_str(), "string",
				unit.c_str(), "both", 15, 0, group_.c_str(), cluster_.c_str(), "", "");
		}
		void sendMetric_(std::string name, int value, std::string unit)
		{
			send_gmetric(name.c_str(), std::to_string(value).c_str(),
				"int32", unit.c_str(), "both", 15, 0, group_.c_str(), cluster_.c_str(), "", "");
		}
		void sendMetric_(std::string name, double value, std::string unit)
		{
			send_gmetric(name.c_str(), std::to_string(value).c_str(),
				"double", unit.c_str(), "both", 15, 0, group_.c_str(), cluster_.c_str(), "", "");
		}
		void sendMetric_(std::string name, float value, std::string unit)
		{
			send_gmetric(name.c_str(), std::to_string(value).c_str(),
				"float", unit.c_str(), "both", 15, 0, group_.c_str(), cluster_.c_str(), "", "");
		}
		void sendMetric_(std::string name, unsigned long int value, std::string unit)
		{
		  send_gmetric(name.c_str(), std::to_string(value).c_str(),
				"uint32", unit.c_str(), "both", 15, 0, group_.c_str(), cluster_.c_str(), "", "");
		}
	};
} //End namespace artdaq

DEFINE_ARTDAQ_METRIC(artdaq::GangliaMetric)

#endif //End ifndef __GANGLIA_METRIC__
